@@ -47,6 +47,8 @@ DB_CREDENTIALS = CONFIG["DB"]
 
 SERVICE_CODE = CONFIG['APP']['service_code']
 
+TMIRA = CONFIG["URLS"]["tmira"]
+
 CHANNEL_LIST = {
     "1": {"name": "BLUELINE TV"},
     "2": {"name": "TVM"},
@@ -184,7 +186,6 @@ CATEGORIE = {
         "Animaux TV",
         "TREK",
         "ECTV",
-        "ARTE",
         "KTO",
         "NatGeo",
         "NatGeoWild",
@@ -301,4 +302,86 @@ CACHE = {
     "506": {"name": "Voice of America"}
     }
 
+
+CH = {
+    'Automoto': '65',
+    'AB1': '41',
+    'AB3': '43',
+    'Action': '83',
+    'AfricaNews': '24',
+    'Al Jazeera': '29',
+    'Animaux TV': '74',
+    'Antenne Reunion': '17',
+    'BFM TV': '23',
+    'BLUELINE TV': '1',
+    'Boing TV': '34',
+    'Boomerang': '35',
+    'CCTV-4': '27',
+    'CNN': '25',
+    'CTV': '85',
+    'CTV2': '86',
+    'Canal J': '33',
+    'Cartoon Network': '31',
+    'Chaine du mois': '9',
+    'Crime District': '82',
+    'DORCEL TV': '109',
+    "Dream'In": '7',
+    'E!': '45',
+    'ES1': '40',
+    'English Club TV': '39',
+    'Fashion TV': '90',
+    'ESPN': '64',
+    'France 2': '12',
+    'France 24': '20',
+    'France 24 English': '21',
+    'France 3': '13',
+    'France 5': '15',
+    'France Culture': '502',
+    'France Info': '501',
+    'France Inter': '503',
+    'France O': '44',
+    'Gulli': '30',
+    'Histoire': '70',
+    'KTO': '77',
+    'LCI': '22',
+    'Le Moov': '504',
+    'M6': '16',
+    'MCM': '50',
+    'MCM Top': '51',
+    'MCS': '66',
+    'Mangas': '38',
+    'Mezzo': '59',
+    'NatGeo': '78',
+    'NatGeoWild': '79',
+    'Nina TV': '42',
+    'Passions TV': '48',
+    'RECORD TV': '4',
+    'RFI': '505',
+    'RFM TV': '53',
+    'RTA': '3',
+    'RTL9': '49',
+    'SERIES': '47',
+    'STREAMING': '8',
+    'Science et Vie TV': '72',
+    'TCM Cinema': '80',
+    'TF1': '11',
+    'TFX': '46',
+    'TMC': '18',
+    'TOONAMI': '36',
+    'TREK': '68',
+    'TV5 Style': '75',
+    'TV5MONDE': '10',
+    'TVM': '2',
+    'Tiji': '32',
+    'Tivi5MONDE': '37',
+    'Ushuaia TV': '73',
+    'VIVA': '5',
+    'Voice of America': '28',
+    'Voyage': '71',
+    'W9': '19',
+    'beIN SPORTS 1': '61',
+    'beIN SPORTS 2': '62',
+    'beIN SPORTS 3': '63',
+    'i-BC': '6'
+    }
 # EOF
